@@ -258,7 +258,7 @@ getImages1 dir images theWikiUrl
   = do liftIO $
          do let ddir = dir
             let thetheWikiUrl = theWikiUrl
-            let iimages = ((zip [1 ..] (map premap images)))
+            let iimages = ((zip [1 ..] (map (premap2 . premap) images)))
             helper<-(mapM (doImage1 ddir thetheWikiUrl) iimages)
             let l = map first helper
             let hosts = concat (repeat (map hof (parses theWikiUrl)))
@@ -281,6 +281,9 @@ getImages1 dir images theWikiUrl
             authorList<-mapM fun2 imgdescfiles
             mapM (getCredits dir) (zip (makautlist authorList) (zip images (zip ([1..(length images)]) imgdescurls)))
   where
+    premap2 x = case splitOn "?lang=" x of
+                 (y:_) -> y
+                 _->x
     premap x = case splitOn "?page=" x of
                  (y:_) -> y
                  _->x
