@@ -341,6 +341,31 @@ htmlchars
      ("rarr", "{\\mbox{$\\rightarrow$}}"),
      ("darr", "{\\mbox{$\\downarrow$}}"),
      ("harr", "{\\mbox{$\\leftrightarrow$}}"),
+     ("varr", "{\\mbox{$\\updownarrow$}}"),
+     
+     ("8658", "{\\mbox{$\\Leftarrow$}}"),
+     ("8657", "{\\mbox{$\\Uparrow$}}"),
+     ("8656", "{\\mbox{$\\Rightarrow$}}"),
+     ("8659", "{\\mbox{$\\Downarrow$}}"),
+     ("8660", "{\\mbox{$\\Leftrightarrow$}}"),
+     ("8661", "{\\mbox{$\\Updownarrow$}}"),
+     
+     ("8592", "{\\mbox{$\\leftarrow$}}"),
+     ("8593", "{\\mbox{$\\uparrow$}}"),
+     ("8594", "{\\mbox{$\\rightarrow$}}"),
+     ("8595", "{\\mbox{$\\downarrow$}}"),
+     ("8596", "{\\mbox{$\\leftrightarrow$}}"),
+     ("8597", "{\\mbox{$\\updownarrow$}}"),
+     
+     
+     ("lArr", "{\\mbox{$\\Leftarrow$}}"),
+     ("uArr", "{\\mbox{$\\Uparrow$}}"),
+     ("rArr", "{\\mbox{$\\Rightarrow$}}"),
+     ("dArr", "{\\mbox{$\\Downarrow$}}"),
+     ("hArr", "{\\mbox{$\\Leftrightarrow$}}"),
+     ("vArr", "{\\mbox{$\\Updownarrow$}}"),
+     
+     
      ("#160", "{\\mbox{$~$}}"), ("nbsp", "{\\mbox{$~$}}"),
      ("#162", "{\\mbox{$\\cent$}}"), ("cent", "{\\mbox{$\\cent$}}"),
      ("#163", "{\\mbox{$\\pounds$}}"), ("#165", "{\\mbox{$\\yen$}}"),
@@ -541,7 +566,7 @@ goodtags1
      "video", "audio", "style", "input", "label", "tbody", "thead",
      "title", "track" ,"frame", "param", "base", "area", "font", "code", "span", "main",
      "abbr", "body", "link", "menu", "math", "meta", "samp", "cite",
-     "head", "html", "poem", "form", "cite", "ref", "div", "pre", "sub", "nav",
+     "head", "html", "form", "cite", "ref", "div", "pre", "sub", "nav",
      "sup", "big", "del", "map", "bdo", "var", "dfn", "kbd", "col", "wbr",
      "ins", "bdi", "dir", "img", "h1", "h2", "h3", "h4", "h5", "h6",
      "li", "ul", "ol", "tt", "dd", "dl", "dt", "hr", "em", "b", "i",
